summaryrefslogtreecommitdiff
path: root/sc/source/filter/inc/ftools.hxx
diff options
context:
space:
mode:
authorIvo Hinkelmann <ihi@openoffice.org>2006-12-19 12:23:44 +0000
committerIvo Hinkelmann <ihi@openoffice.org>2006-12-19 12:23:44 +0000
commit5151f72815e9bf5123afe89cdf35736351a81c09 (patch)
tree2f77ea607837eece07835d8fe56bf875d426c76a /sc/source/filter/inc/ftools.hxx
parent08d9b5b490d04b62f8a7391a1b98f02dedd3ed64 (diff)
INTEGRATION: CWS dr51 (1.19.146); FILE MERGED
2006/11/08 09:30:36 dr 1.19.146.1: #i71033# use app-font text encoding if CODEPAGE is missing, remane 'CharSet' -> 'rtl_TextEncoding'
Diffstat (limited to 'sc/source/filter/inc/ftools.hxx')
-rw-r--r--sc/source/filter/inc/ftools.hxx18
1 files changed, 9 insertions, 9 deletions
diff --git a/sc/source/filter/inc/ftools.hxx b/sc/source/filter/inc/ftools.hxx
index 63507c818def..6d19b3440488 100644
--- a/sc/source/filter/inc/ftools.hxx
+++ b/sc/source/filter/inc/ftools.hxx
@@ -4,9 +4,9 @@
*
* $RCSfile: ftools.hxx,v $
*
- * $Revision: 1.19 $
+ * $Revision: 1.20 $
*
- * last change: $Author: rt $ $Date: 2006-05-05 09:41:06 $
+ * last change: $Author: ihi $ $Date: 2006-12-19 13:23:44 $
*
* The Contents of this file are made available subject to
* the terms of GNU Lesser General Public License Version 2.1.
@@ -262,8 +262,8 @@ public:
/** Reads a 10-byte-long-double and converts it to double. */
static double ReadLongDouble( SvStream& rStrm );
- /** Returns system charset for byte string conversion. */
- static CharSet GetSystemCharSet();
+ /** Returns system text encoding for byte string conversion. */
+ static rtl_TextEncoding GetSystemTextEncoding();
/** Returns a string representing the hexadecimal value of nValue. */
static String GetHexStr( sal_uInt16 nValue );
@@ -349,19 +349,19 @@ public:
/** Reads and returns a zero terminted byte string. */
static ByteString ReadCString( SvStream& rStrm );
/** Reads and returns a zero terminted byte string. */
- inline static String ReadCString( SvStream& rStrm, CharSet eSrc )
- { return String( ReadCString( rStrm ), eSrc ); }
+ inline static String ReadCString( SvStream& rStrm, rtl_TextEncoding eTextEnc )
+ { return String( ReadCString( rStrm ), eTextEnc ); }
/** Reads and returns a zero terminted byte string and decreases a stream counter. */
static ByteString ReadCString( SvStream& rStrm, sal_Int32& rnBytesLeft );
/** Reads and returns a zero terminted byte string and decreases a stream counter. */
- inline static String ReadCString( SvStream& rStrm, sal_Int32& rnBytesLeft, CharSet eSrc )
- { return String( ReadCString( rStrm, rnBytesLeft ), eSrc ); }
+ inline static String ReadCString( SvStream& rStrm, sal_Int32& rnBytesLeft, rtl_TextEncoding eTextEnc )
+ { return String( ReadCString( rStrm, rnBytesLeft ), eTextEnc ); }
/** Appends a zero terminted byte string. */
static void AppendCString( SvStream& rStrm, ByteString& rString );
/** Appends a zero terminted byte string. */
- static void AppendCString( SvStream& rStrm, String& rString, CharSet eSrc );
+ static void AppendCString( SvStream& rStrm, String& rString, rtl_TextEncoding eTextEnc );
// *** HTML table names <-> named range names *** -----------------------------